/*
   ===============================================================================
Name        : W5500-EVB.c
Author      : $(author)
Version     :
Copyright   : $(copyright)
Description : main definition
===============================================================================
*/

#if defined (__USE_LPCOPEN)
#if defined(NO_BOARD_LIB)
#include "chip.h"
#else
#include "board.h"
#endif
#endif

#include "socket.h"
#include "spi_handler.h"
#include "w5500_init.h"

#include <cr_section_macros.h>

// TODO: insert other include files here

// TODO: insert other definitions and declarations here
#define SOCK_TCPS0       0
#define DATA_BUF_SIZE   2048
uint8_t gDATABUF[DATA_BUF_SIZE];

int32_t loopback_tcps(uint8_t sn, uint8_t* buf, uint16_t port)
{
	int32_t ret;
	uint16_t size = 0, sentsize=0;
	switch(getSn_SR(sn)) {
		case SOCK_ESTABLISHED :
			if(getSn_IR(sn) & Sn_IR_CON) {
				printf("%d:Connected\r\n",sn);
				setSn_IR(sn,Sn_IR_CON);
			}
			if((size = getSn_RX_RSR(sn)) > 0) {
				if(size > DATA_BUF_SIZE) size = DATA_BUF_SIZE;
				ret = recv(sn,buf,size);
				if(ret <= 0) return ret;
				sentsize = 0;
				while(size != sentsize) {
					ret = send(sn,buf+sentsize,size-sentsize);
					if(ret < 0) {
						close(sn);
						return ret;
					}
					sentsize += ret; // Don't care SOCKERR_BUSY, because it is zero.
				}
			}
			break;
		case SOCK_CLOSE_WAIT :
			printf("%d:CloseWait\r\n",sn);
			if((ret=disconnect(sn)) != SOCK_OK) return ret;
			printf("%d:Closed\r\n",sn);
			break;
		case SOCK_INIT :
			printf("%d:Listen, port [%d]\r\n",sn, port);
			if( (ret = listen(sn)) != SOCK_OK) return ret;
			break;
		case SOCK_CLOSED:
			printf("%d:LBTStart\r\n",sn);
			if((ret=socket(sn,Sn_MR_TCP,port,0x00)) != sn)
				return ret;
			printf("%d:Opened\r\n",sn);
			break;
		default:
			break;
	}
	return 1;
}

int main(void) {
	int ret;

#if defined (__USE_LPCOPEN)
#if !defined(NO_BOARD_LIB)
	// Read clock settings and update SystemCoreClock variable
	SystemCoreClockUpdate();
	// Set up and initialize all required blocks and
	// functions related to the board hardware
	Board_Init();
	// Set the LED to the state of "On"
	Board_LED_Set(0, true);
#endif
#endif
	SPI_Init();
	W5500_Init();
	Net_Conf();

	while(1) {
		if((ret = loopback_tcps(SOCK_TCPS0, gDATABUF, 5000)) < 0) {
			printf("SOCKET ERROR : %ld\r\n", ret);
		}
	}
	return 0 ;
}
